#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QVBoxLayout>


MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    tree = new QTreeWidget(this);
    tree->setColumnCount(2);
    QStringList headers;
    headers<<QString::fromLocal8Bit("")<<"ID";
    tree->setHeaderLabels(headers);
    for (int i = 0; i < tree->columnCount(); ++i)
        tree->headerItem()->setTextAlignment(i, Qt::AlignCenter);
    tree->setAlternatingRowColors(true);
    tree->setStyleSheet("font-size: 12px;");
    tree->setSortingEnabled(true);
    setCentralWidget(tree);

    nodes.push_back(NodeParams(1,"",0));
    nodes.push_back(NodeParams(2," ",1));
    nodes.push_back(NodeParams(3," ",2));
    nodes.push_back(NodeParams(4," ",2));
    nodes.push_back(NodeParams(5," ",2));
    nodes.push_back(NodeParams(6," ",2));
    nodes.push_back(NodeParams(7," ",2));
    nodes.push_back(NodeParams(8," ",2));
    nodes.push_back(NodeParams(9,"- ",1));
    nodes.push_back(NodeParams(10," ",9));
    nodes.push_back(NodeParams(11," ",9));
    nodes.push_back(NodeParams(12," ",9));
    nodes.push_back(NodeParams(13," ",9));
    nodes.push_back(NodeParams(14," ",9));
    nodes.push_back(NodeParams(15," ",9));
    nodes.push_back(NodeParams(16," ",1));
    nodes.push_back(NodeParams(17,"",16));
    nodes.push_back(NodeParams(18,"",16));
    nodes.push_back(NodeParams(19,"",16));
    nodes.push_back(NodeParams(20,"",9));
    nodes.push_back(NodeParams(21,"",9));

    cameras.push_back(CameraParams(686," .3(H)",12));
    cameras.push_back(CameraParams(684," .2(H)",12));
    cameras.push_back(CameraParams(682," .1(H)",12));

    buildTree();
    tree->setFocus();
    connect(tree, SIGNAL(itemExpanded(QTreeWidgetItem*)), this, SLOT(resizeColumns(QTreeWidgetItem*)));
    connect(tree, SIGNAL(itemCollapsed(QTreeWidgetItem*)), this, SLOT(resizeColumns(QTreeWidgetItem*)));
    resizeColumns(NULL);
}


MainWindow::~MainWindow()
{
    delete ui;
}


void MainWindow::resizeColumns(QTreeWidgetItem* item)
{
    for (int i = 0; i < tree->columnCount(); ++i)
        tree->resizeColumnToContents(i);
}


void MainWindow::buildTree()
{
    tree->clear();
    for (unsigned int i = 0; i < nodes.size(); ++i)
    {
        if (nodes[i].parentid == 0)
        {
            QTreeWidgetItem* item = new QTreeWidgetItem(tree);
            item->setText(0, QString::fromLocal8Bit(nodes[i].name.c_str()));
            addChilds(item, nodes[i].id);
            if (!item->childCount())
                delete item;
        }
    }
}


void MainWindow::addChilds(QTreeWidgetItem* item, int id)
{
    QTreeWidgetItem* child;
    for (unsigned int i = 0; i < nodes.size(); ++i)
    {
        if (nodes[i].parentid == id)
        {
            child = new QTreeWidgetItem(item);
            child->setText(0, QString::fromLocal8Bit(nodes[i].name.c_str()));
            addChilds(child, nodes[i].id);

            if (!child->childCount())
            {
                /*   ,    */
                //item->removeChild(child);
                delete child;
            }
        }
    }
    for (unsigned int i = 0; i < cameras.size(); ++i)
    {
        if (cameras[i].nodeid == id)
        {
            QString camName = QString::fromLocal8Bit(cameras[i].name.c_str());
            QString camId = QString::number(cameras[i].id);
            child = new QTreeWidgetItem(item);
            child->setText(1, camId);
            child->setText(0, camName);
        }
    }
}
